<?php
/*
		Plugin Name: Proofread Bot
		Plugin URI: http://proofreadbot.com
		Description: Grammar, style and plagiarism checker
		Version: 2.18
		Author: Gyorgy Chityil
		Author URI: http://proofreadbot.com
	*/

include('classes/proofread_bot_api.php');

//TINYMC RELATED


/*
		*  Load necessary include files
	*/
include( 'config-options.php' );
include( 'utils.php' );
include( 'proxy.php' );
/*
		*  Code to update the toolbar with the AtD Button and Install the AtD TinyMCE Plugin
	*/
function proofread_bot_addbuttons() {
	
	/* Don't bother doing this stuff if the current user lacks permissions */
	if ( ! current_user_can('edit_posts') && !current_user_can('edit_pages') )
	return;
	
	/* Add only in Rich Editor mode w/ Blog language ID set to English */
	if ( get_user_option('rich_editing') == 'true' ) {
		add_filter( 'mce_external_plugins', 'add_proofread_bot_tinymce_plugin' );
		add_filter( 'mce_buttons', 'register_proofread_bot_button' );
	}
	
	//add_action( 'personal_options_update', 'proofread_bot_process_options_update' );
	//add_action( 'personal_options_update', 'proofread_bot_process_unignore_update' );
	//add_action( 'profile_personal_options', 'proofread_bot_config' );
}


/*
		* Hook into the TinyMCE buttons and replace the current spellchecker
	*/
function register_proofread_bot_button( $buttons ) 
{
	
	/* kill the spellchecker.. don't need no steenkin PHP spell checker */
	foreach ( $buttons as $key => $button ) {
		if ( $button == 'spellchecker' ) {
			$buttons[$key] = 'proofread_bot';
			return $buttons;
			}
	}
	
	/* hrm... ok add us last plz */
	array_push( $buttons, 'separator', 'proofread_bot' );
	return $buttons;
}

/*
		* Load the TinyMCE plugin : editor_plugin.js (wp2.5)
	*/
function add_proofread_bot_tinymce_plugin( $plugin_array ) {
	$plugin_array['proofread_bot'] = WP_PLUGIN_URL . '/proofread-bot/tinymce/editor_plugin.js';
	return $plugin_array;
}

/*
		* Update the TinyMCE init block with proofread_bot specific settings
	*/
function proofread_bot_change_mce_settings( $init_array ) {
	
	/* grab our user and validate their existence */
	$user = wp_get_current_user();
	if ( ! $user || $user->ID == 0 )
	return;
	
	$init_array['proofread_bot_rpc_url']        = admin_url() . 'admin-ajax.php?action=proxy_proofread_bot&url=';
	$init_array['proofread_bot_ignore_rpc_url'] = admin_url() . 'admin-ajax.php?action=proofread_bot_ignore&phrase=';
	$init_array['proofread_bot_rpc_id']         = 'WPORG-' . md5(get_bloginfo('wpurl'));
	$init_array['proofread_bot_theme']          = 'wordpress';
	$init_array['proofread_bot_ignore_enable']  = 'true';
	$init_array['proofread_bot_strip_on_get']   = 'true';
	$init_array['proofread_bot_ignore_strings'] = str_replace( '"', '', proofread_bot_get_setting( $user->ID, 'proofread_bot_ignored_phrases' ) );
	$init_array['proofread_bot_show_types']     = proofread_bot_get_setting( $user->ID, 'proofread_bot_options' );
	$init_array['gecko_spellcheck']   = 'false';
	
	return $init_array;
}



/*
		* Sanitizes proofread_bot AJAX data to acceptable chars, caller needs to make sure ' is escaped
	*/
function proofread_bot_sanitize( $untrusted ) {
	return preg_replace( '/[^a-zA-Z0-9\-\',_ ]/i', "", $untrusted );
}

/*
		* proofread_bot HTML Editor Stuff
	*/

function proofread_bot_settings() {
	$user = wp_get_current_user();
	
	header( 'Content-Type: text/javascript' );
	
	/* set the RPC URL for proofread_bot */
	echo "proofread_bot.rpc = '" . admin_url() . "admin-ajax.php?action=proxy_proofread_bot&url=';\n";
	
	/* set the API key for proofread_bot */
	echo "proofread_bot.api_key = 'WPORG-" . md5(get_bloginfo('wpurl')) . "';\n";
	
	/* set the ignored phrases for proofread_bot */
	echo "proofread_bot.setIgnoreStrings('" . str_replace( "'", "\\'", proofread_bot_get_setting( $user->ID, 'proofread_bot_ignored_phrases' ) ) . "');\n";
	
	/* honor the types we want to show */
	echo "proofread_bot.showTypes('" . str_replace( "'", "\\'", proofread_bot_get_setting( $user->ID, 'proofread_bot_options' ) ) ."');\n";
	
	/* this is not an proofread_bot/jQuery setting but I'm putting it in proofread_bot to make it easy for the non-viz plugin to find it */
	echo "proofread_bot.rpc_ignore = '" . admin_url() . "admin-ajax.php?action=proofread_bot_ignore&phrase=';\n";
	
	die;
}

function proofread_bot_load_javascripts() {
	global $pagenow;
	
	if ( proofread_bot_should_load_on_page() ) {
		wp_enqueue_script( 'proofread_bot_core', WP_PLUGIN_URL . '/proofread-bot/proofread_bot.core.js', array() );
		//wp_enqueue_script( 'proofread_bot_quicktags', WP_PLUGIN_URL . '/proofread-bot/proofread_bot-nonvis-editor-plugin.js', array('quicktags') );
		//wp_enqueue_script( 'proofread_bot_jquery', WP_PLUGIN_URL . '/proofread-bot/jquery.proofread_bot.js', array('jquery') );
		//wp_enqueue_script( 'proofread_bot_settings', admin_url() . 'admin-ajax.php?action=proofread_bot_settings', array('proofread_bot_jquery') );
		//wp_enqueue_script( 'proofread_bot_autoproofread', WP_PLUGIN_URL . '/proofread-bot/proofread_bot-autoproofread.js', array('proofread_bot_jquery') );
		// A style available in WP               
		//wp_enqueue_style (  'wp-jquery-ui-dialog');
		wp_enqueue_style('jquery-style', 'http://ajax.googleapis.com/ajax/libs/jqueryui/1.8.1/themes/smoothness/jquery-ui.css'); 
	}
}


/* Spits out user options for auto-proofreading on publish/update */
function proofread_bot_load_submit_check_javascripts() {
	global $pagenow;
	
	$user = wp_get_current_user();
	if ( ! $user || $user->ID == 0 )
	return;
	
	if ( proofread_bot_should_load_on_page() ) {
		$proofread_bot_check_when = proofread_bot_get_setting( $user->ID, 'proofread_bot_check_when' );
		if ($proofread_bot_check_when) {
			$check_when = '';
			/* Set up the options in json */
			foreach( explode( ',', $proofread_bot_check_when ) as $option ) {
				$check_when .= ($check_when ? ', ' : '') . $option . ': true';
			}
			echo '<script type="text/javascript">' . "\n";
			echo 'proofread_bot_check_when = { ' . $check_when . ' };' . "\n";
			echo '</script>' . "\n";
		}
	}
}

function proofread_bot_is_allowed() {
	$user = wp_get_current_user();
	if ( ! $user || $user->ID == 0 )
	return;
	
	if ( ! current_user_can('edit_posts') && ! current_user_can('edit_pages') )
	return;
	
	return 1;
}

function proofread_bot_load_css() {
	if ( proofread_bot_should_load_on_page() )
	wp_enqueue_style( 'proofread_bot_style', WP_PLUGIN_URL . '/proofread-bot/proofread_bot.css', null, '1.0', 'screen' );
}

/* Helper used to check if javascript should be added to page. Helps avoid bloat in admin */
function proofread_bot_should_load_on_page() {
	global $pagenow;
	
	//$pages = array('post.php', 'post-new.php', 'page.php', 'page-new.php', 'admin.php', 'profile.php');
	$pages = array('post.php', 'post-new.php', 'page.php', 'page-new.php', 'admin.php', 'profile.php', 'widgets.php');
	
	if( in_array($pagenow, $pages) )
	return true;
	
	return false;
}




/* add some vars into the proofread_bot plugin */
add_filter( 'tiny_mce_before_init', 'proofread_bot_change_mce_settings' );

/* load some stuff for non-visual editor */
add_action( 'admin_print_scripts', 'proofread_bot_load_javascripts' );
//add_action( 'admin_print_scripts', 'proofread_bot_load_submit_check_javascripts' );
add_action( 'admin_print_styles', 'proofread_bot_load_css' );

/* init process for button control */
add_action( 'init', 'proofread_bot_addbuttons' );

/* setup hooks for our PHP functions we want to make available via an AJAX call */
add_action( 'wp_ajax_proxy_proofread_bot', 'proofread_bot_redirect_call' );
add_action( 'wp_ajax_proofread_bot_ignore', 'proofread_bot_ignore_call' );
add_action( 'wp_ajax_proofread_bot_settings', 'proofread_bot_settings' );



// TINYMCE END


/*
		* Set up options, convert old options, add filters if automatic display is enabled, and enqueue scripts
		* @uses get_option, update_option, add_filter, wp_enqueue_script
		* @return null
	*/

/* Define the custom box */
add_action( 'add_meta_boxes', 'proofread_bot_add_custom_box' );


/* Adds a box to the main column on the Post and Page edit screens */
function proofread_bot_add_custom_box() {
	
	add_meta_box( 
	'proofread_bot',
	__( 'Proofread Bot Report', 'proofread_bot_textdomain' ),
	'proofread_bot_inner_custom_box',
	'post' 
	);
	
	add_meta_box( 
	'proofread_bot',
	__( 'Proofread Bot Report', 'proofread_bot_textdomain' ),
	'proofread_bot_inner_custom_box',
	'page'
	);
}

/* Prints the box content */
function proofread_bot_inner_custom_box( $post ) {
	
	// Use nonce for verification
	wp_nonce_field( plugin_basename( __FILE__ ), 'proofread_bot_noncename' );
	
	// The actual fields for data entry
	//echo '<label for="proofread_bot_new_field">';
	//_e("Proofread Bot results will appear here", 'proofread_bot_textdomain' );
	//echo '</label> ';
	echo '<button type="button"  id="proofread_bot-submit" onclick="return false;">Get your Proofread Bot Report</button>
		<div id="proofread_bot_result"></div>';
	echo '<script>        
		jQuery(document).ready(function(){
		
		//console.log(tinyMCE.activeEditor.getContent(content));
		
		jQuery("#proofread_bot-submit").click(function(event){
		var proofread_bot_text;
		
		// standard tinymce
		if (jQuery("#content_ifr").contents().find("#tinymce").html() !== "")
		proofread_bot_text = jQuery("#content_ifr").contents().find("#tinymce").html();
		
		// tinymce advanced
		if (jQuery("#content").html() !== "")
		proofread_bot_text = jQuery("#content").html();
		
		if (proofread_bot_text === null || proofread_bot_text === ""  || proofread_bot_text === "undefined"  || proofread_bot_text === "<p><br data-mce-bogus=\"1\"></p>" || proofread_bot_text === "<p><br></p>" )
		{
		jQuery("#proofread_bot-submit").after("<br/>Failed to get text from editor, please try switching to \"Visual\" if you use TinyMCE Advanced or report the issue at http://proofreadbot.com/support-forum mentioning your Wysiwyg extension, such as CKEditor etc...");
		}
		else
		{
		jQuery("#proofread_bot-submit").after("<div id=\"proofread_bot_throbber\"><img src=\"'. WP_PLUGIN_URL.'/proofread-bot/throbber.gif\" /> Fetching report, may take a few seconds...</div>");
		
		var data = {
		action: \'post_check_proofread_bot\',
		"text": proofread_bot_text
		};
		
		// since 2.8 ajaxurl is always defined in the admin header and points to admin-ajax.php
		jQuery.post(ajaxurl, data, function(response) {
		jQuery("#proofread_bot-submit").after(response);
		jQuery("#proofread_bot_throbber").remove(); 
		});	
		}
		});
		});
		</script>';
}

// AJAX
add_action('wp_ajax_post_check_proofread_bot', 'proofread_bot_post_ajax_check');

function proofread_bot_post_ajax_check()
{   
	$post = $_POST['text'];
	
	if(current_user_can('check_proofread_bot'))
	{
		//if (strpos($post, "&lt;") !== 'false')
		//	$post = html_entity_decode($post);
		
		//print_r($post);
		//die;
		
		$node = proofread_bot_check_api($post);
		if(isset($node->field_html_report_text)) {
		print_r($node->field_html_report_text->und[0]->value);
		}
		else {
		print_r($node);
		}
	}
	
	
	die();
}


function proofread_bot_setup() {
	//Add filters if set to automatic display
	add_filter( 'the_content', 'proofread_bot_auto' );
	//if( $options[ 'display' ] == 1 && $options[ 'content-excerpt' ] == 1 ) add_filter( 'the_excerpt', 'proofread_bot_auto' );
}
add_action( 'plugins_loaded', 'proofread_bot_setup' );


function proofread_bot_auto( $content ) {
	global $post;
	$options = get_option('proofread_bot_options');
	//print_r($options);
	
	$button_link="http://www.proofreadbot.com";
	if(strlen($options['proofread_bot_affiliate_id']) > 0) 
	{
		$button_link="http://".$options['proofread_bot_affiliate_id'].".proofbot.hop.clickbank.net/\" rel=\"nofollow";
	}
	
	$button = "<a href=\"".$button_link."\" target=\"_blank\"><img src=\"". WP_PLUGIN_URL ."/proofread-bot/buttons/small_".$options["proofread_bot_button"]."-button1-".$options["proofread_bot_button_color"].".png\" /></a>";
	
	//print $button;
	
	//Add button to $content
	if( $options[ 'proofread_bot_placement_posts' ] == true)  
	$content = $content . $button;
	
	
	return $content;
	
}

add_action('admin_menu', 'proofread_botoptions_add_page_fn');
// Add sub page to the Settings Menu
function proofread_botoptions_add_page_fn() {
	add_options_page('Proofread Bot', 'Proofread Bot', 'administrator', __FILE__, 'proofread_bot_options_page');
}

function proofread_bot_options_page() {
	?>
	<div class="wrap">
	<div class="icon32" id="icon-options-general"><br></div>
	<h2>Proofread Bot Options</h2>
	You can use Proofread Bot plugin without filling out the account details here, and you have 1 free proofread credit (600 words) per day. For more checks please <a href="http://proofreadbot.com/invite-your-friends" target="_blank">invite your friends <img src="<?php print WP_PLUGIN_URL ?>/proofread-bot/facebook.png" /></a> or <a href="http://proofreadbot.com/node/2">purchase a package</a>, 1 automated proofread credit = 1 friend invite or 0.01$ (1 cent).
	<form action="options.php" method="post">
	<?php settings_fields('proofread_bot_options'); ?>
	<?php do_settings_sections(__FILE__); ?>
	<p class="submit">
	<input name="Submit" type="submit" class="button-primary" value="<?php esc_attr_e('Save Changes'); ?>" />
	</p>
	</form>
	</div>
	<?php
}

add_action('admin_init', 'proofread_botsoptions_init_fn' );
// Register our settings. Add the settings section, and settings fields
function proofread_botsoptions_init_fn(){
	register_setting('proofread_bot_options', 'proofread_bot_options', 'proofread_bot_options_validate' );
	
	add_settings_section('main_section', 'Proofread Bot Account Details', 'proofread_bot_section_text_fn', __FILE__);
	
	add_settings_field('proofread_bot_username', 'Proofread Bot Username', 'proofread_bot_setting_username_fn', __FILE__, 'main_section');
	add_settings_field('proofread_bot_password', 'Proofread Bot Password', 'proofread_bot_setting_password_fn', __FILE__, 'main_section');
	add_settings_field('min_user_level', 'Lowest Role that can check Proofread Bot', 'proofread_bot_setting_role_fn', __FILE__, 'main_section');
	
	add_settings_section('button_section', 'Proofread Bot Button Settings', 'proofread_bot_button_section_text_fn', __FILE__);
	
	add_settings_field('proofread_bot_button', 'Select Button', 'proofread_bot_setting_button_fn', __FILE__, 'button_section');
	add_settings_field('proofread_bot_button_color', 'Select Button Color', 'proofread_bot_setting_button_color_fn', __FILE__, 'button_section');
	// add_settings_field('proofread_bot_button_placement_homepage', 'Show button on homepage', 'proofread_bot_setting_button_placement_homepage_fn', __FILE__, 'button_section');
	add_settings_field('proofread_bot_button_placement_posts', 'Show button on posts', 'proofread_bot_setting_button_placement_posts_fn', __FILE__, 'button_section');
	
	add_settings_section('affiliate_section', 'Proofread Bot Affiliate Program - Make Money', 'proofread_bot_affiliate_section_text_fn', __FILE__);
	add_settings_field('proofread_bot_affiliate_id', 'Proofread Bot Affiliate Id', 'proofread_bot_setting_affiliate_id_fn', __FILE__, 'affiliate_section');
	
	// add custom capability depending on settings
	$options = get_option('proofread_bot_options');
	$min_role = $options ? $options['role'] : 'administrator' ;
	$roles = array('Administrator'=>'administrator', 'Editor'=>'editor', 'Author'=>'author', 'Contributor'=>'contributor');
	
	foreach($roles as $role=>$val)
	{
		$role = get_role($val);
		$role->add_cap( 'check_proofread_bot' );
		
		if($val == $min_role)
		break;
	}
}

function proofread_bot_section_text_fn()
{
	echo '<p>Enter your Proofread Bot account details.</p>';
}

function proofread_bot_button_section_text_fn()
{
	echo '<p>Select optionally a button to show your visitors you care about grammar and style on your site! You can also make some money by participating in the Proofread Bot affiliate program.</p>';
}

function proofread_bot_affiliate_section_text_fn()
{
	echo '<p>Make money by participating in the Proofread Bot affiliate program, powered by Clickbank. The button you selected will link with your clickbank id so referrals can be credited to you. If you don\'t have a clickbank id  get it  <a rel="nofollow" href="http://proofreadbot.com/affiliate/signup" target="_blank">here</a>, you will be taken to the Clickbank vendor / affiliate signup page. (Vendor and affiliate accounts are the same at Clickbank.)</p>';
}

function proofread_bot_options_validate($input) {
	// Check our textbox option field contains no HTML tags - if so strip them out
	return $input; // return validated input
}

function proofread_bot_setting_role_fn() {
	$options = get_option('proofread_bot_options');
	$items = array('Administrator'=>'administrator', 'Editor'=>'editor', 'Author'=>'author', 'Contributor'=>'contributor');
	
	echo "<select id='proofread_bot_role' name='proofread_bot_options[role]'>";
	
	foreach($items as $item=>$value)
	{
		$selected = ($options['role']== $value ) ? 'selected="selected"' : '';
		echo "<option value='$value' $selected>$item</option>";
	}
	
	echo "</select>";
}

function proofread_bot_setting_username_fn() {
	$options = get_option('proofread_bot_options');
	echo "<input name='proofread_bot_options[proofread_bot_username]' size='40' type='text' value='{$options['proofread_bot_username']}' />";
}

function proofread_bot_setting_password_fn() {
	$options = get_option('proofread_bot_options');
	echo "<input name='proofread_bot_options[proofread_bot_password]' size='40' type='text' value='{$options['proofread_bot_password']}' />";
}

function proofread_bot_setting_affiliate_id_fn() {
	$options = get_option('proofread_bot_options');
	echo "<input name='proofread_bot_options[proofread_bot_affiliate_id]' size='40' type='text' value='{$options['proofread_bot_affiliate_id']}' />";
}


function proofread_bot_setting_button_fn() {
	$options = get_option('proofread_bot_options');
	//print_r($options);
	?>
	<fieldset>
	<label><input name='proofread_bot_options[proofread_bot_button]' value='proofreadbot' type='radio' <?php if( !$options['proofread_bot_button'] || $options['proofread_bot_button']=='proofreadbot' ) echo ' checked="checked"'; ?>>
	<img src="<?php echo WP_PLUGIN_URL ?>/proofread-bot/buttons/small_proofreadbot-button1-light.png" /></label><br/>
	<label><input name='proofread_bot_options[proofread_bot_button]' value='perfect_grammar' type='radio' <?php if( !$options['proofread_bot_button'] || $options['proofread_bot_button']=='perfect_grammar' ) echo ' checked="checked"'; ?>>
	<img src="<?php echo WP_PLUGIN_URL ?>/proofread-bot/buttons/small_perfect_grammar-button1-light.png" /></label>
	</fieldset> 	
	<?php
}

function proofread_bot_setting_button_color_fn() {
	$options = get_option('proofread_bot_options');
	$items = array('Light'=>'light', 'Dark'=>'dark', 'Green'=>'green', 'Red'=>'red', 'Yellow'=>'yellow', 'Blue'=>'blue');
	
	echo "<select id='proofread_bot_button_color' name='proofread_bot_options[proofread_bot_button_color]'>";
	
	foreach($items as $item=>$value)
	{
		$selected = ($options['proofread_bot_button_color']== $value ) ? 'selected="selected"' : '';
		echo "<option value='$value' $selected>$item</option>";
	}
	
	echo "</select>";
}

function proofread_bot_setting_button_placement_homepage_fn() {
	$options = get_option('proofread_bot_options');
	if( $options['proofread_bot_placement_homepage']== true) 
	$checked = 'checked="checked"';
	
	echo "<input name='proofread_bot_options[proofread_bot_placement_homepage]' type='checkbox' value='true' $checked />";
}

function proofread_bot_setting_button_placement_posts_fn() {
	$options = get_option('proofread_bot_options');
	
	if($options['proofread_bot_placement_posts']== true )
	$checked = 'checked="checked"';
	
	echo "<input name='proofread_bot_options[proofread_bot_placement_posts]' type='checkbox' value='true' $checked />";
}


// Place in Option List on Settings > Plugins page 
function proofread_bot_actlinks( $links, $file ) {
	//Static so we don't call plugin_basename on every plugin row.
	static $this_plugin;
	if ( ! $this_plugin ) $this_plugin = plugin_basename(__FILE__);
	
	if ( $file == $this_plugin ){
		$settings_link = '<a href="options-general.php?page=proofread-bot/proofread_bot.php">' . __('Settings') . '</a>';
		array_unshift( $links, $settings_link ); // before other links
	}
	return $links;
}
add_filter("plugin_action_links", 'proofread_bot_actlinks', 10, 2);

?>